@@ -169,14 +169,13 @@ pub mod keyboard_shortcuts_inhibit {
     }
 }
 
-#[cfg(feature = "unstable")]
 pub mod linux_dmabuf {
     //! Linux DMA-BUF protocol
 
     /// Unstable version 1
     pub mod zv1 {
         wayland_protocol!(
-            "./protocols/unstable/linux-dmabuf/linux-dmabuf-unstable-v1.xml",
+            "./protocols/stable/linux-dmabuf/linux-dmabuf-v1.xml",
             []
         );
     }
@@ -195,6 +194,39 @@ pub mod linux_explicit_synchronization {
     }
 }
 
+#[cfg(feature = "staging")]
+pub mod linux_drm_syncobj {
+    //! This protocol allows clients to request explicit synchronization for
+    //! buffers. It is tied to the Linux DRM synchronization object framework.
+    //!
+    //! Synchronization refers to co-ordination of pipelined operations performed
+    //! on buffers. Most GPU clients will schedule an asynchronous operation to
+    //! render to the buffer, then immediately send the buffer to the compositor
+    //! to be attached to a surface.
+    //!
+    //! With implicit synchronization, ensuring that the rendering operation is
+    //! complete before the compositor displays the buffer is an implementation
+    //! detail handled by either the kernel or userspace graphics driver.
+    //!
+    //! By contrast, with explicit synchronization, DRM synchronization object
+    //! timeline points mark when the asynchronous operations are complete. When
+    //! submitting a buffer, the client provides a timeline point which will be
+    //! waited on before the compositor accesses the buffer, and another timeline
+    //! point that the compositor will signal when it no longer needs to access the
+    //! buffer contents for the purposes of the surface commit.
+    //!
+    //! Linux DRM synchronization objects are documented at:
+    //! <https://dri.freedesktop.org/docs/drm/gpu/drm-mm.html#drm-sync-objects>
+
+    /// Version 1
+    pub mod v1 {
+        wayland_protocol!(
+            "./protocols/staging/linux-drm-syncobj/linux-drm-syncobj-v1.xml",
+            []
+        );
+    }
+}
+
 #[cfg(feature = "unstable")]
 pub mod pointer_constraints {
     //! protocol for constraining pointer motions
@@ -312,7 +344,6 @@ pub mod cursor_shape {
     }
 }
 
-#[cfg(feature = "unstable")]
 pub mod tablet {
     //! Wayland protocol for graphics tablets
     //!
@@ -456,7 +487,6 @@ pub mod security_context {
     //! security contexts are dangerous because they can potentially allow
     //! privilege escalation of a sandboxed client.
 
-
     #[allow(missing_docs)]
     pub mod v1 {
         wayland_protocol!(
@@ -465,3 +495,64 @@ pub mod security_context {
         );
     }
 }
+
+#[cfg(feature = "staging")]
+pub mod alpha_modifier {
+    //! This interface allows a client to set a factor for the alpha values on a
+    //! surface, which can be used to offload such operations to the compositor,
+    //! which can in turn for example offload them to KMS.
+
+    #[allow(missing_docs)]
+    pub mod v1 {
+        wayland_protocol!(
+            "./protocols/staging/alpha-modifier/alpha-modifier-v1.xml",
+            []
+        );
+    }
+}
+
+#[cfg(feature = "staging")]
+pub mod fifo {
+    //! When a Wayland compositor considers applying a content update,
+    //! it must ensure all the update's readiness constraints (fences, etc)
+    //! are met.
+    //!
+    //! This protocol provides a way to use the completion of a display refresh
+    //! cycle as an additional readiness constraint.
+
+    #[allow(missing_docs)]
+    pub mod v1 {
+        wayland_protocol!(
+            "./protocols/staging/fifo/fifo-v1.xml",
+            []
+        );
+    }
+}
+
+#[cfg(feature = "staging")]
+pub mod commit_timing {
+    //! When a compositor latches on to new content updates it will check for
+    //! any number of requirements of the available content updates (such as
+    //! fences of all buffers being signalled) to consider the update ready.
+    //!
+    //! This protocol provides a method for adding a time constraint to surface
+    //! content. This constraint indicates to the compositor that a content
+    //! update should be presented as closely as possible to, but not before,
+    //! a specified time.
+    //!
+    //! This protocol does not change the Wayland property that content
+    //! updates are applied in the order they are received, even when some
+    //! content updates contain timestamps and others do not.
+    //!
+    //! To provide timestamps, this global factory interface must be used to
+    //! acquire a `wp_commit_timing_v1` object for a surface, which may then be
+    //! used to provide timestamp information for commits.
+
+    #[allow(missing_docs)]
+    pub mod v1 {
+        wayland_protocol!(
+            "./protocols/staging/commit-timing/commit-timing-v1.xml",
+            []
+        );
+    }
+}
